@@ -132,9 +132,9 @@ typedef struct sMarkAdContext {
         //!<
         int tStart                     = -1;       //!< offset of timer start to recording start (pre timer)
         //!<
-        sAspectRatio AspectRatio       = {0};      //!< set from info file and checked after chkSTART, valid for the broadcast
+        bool startVPS                  = false;    //!< tStart is from VPS start event
         //!<
-//        short int Channels[MAXSTREAMS] = {0};      //!< count of audio channel of each audio stream
+        sAspectRatio AspectRatio       = {0};      //!< set from info file and checked after chkSTART, valid for the broadcast
         //!<
         char *ChannelName              = nullptr;  //!< name of the channel
         //!<
